@@ -248,6 +248,12 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
 
         return
 
+    def is_editor_area_visible(self):
+        dock_control = self._wx_view_dock_window.get_control(
+            self.editor_area_id, visible_only=False
+        )
+        return dock_control.visible
+        
     #### Methods for saving and restoring the layout ##########################
 
     def get_view_memento(self):
